@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import warnings
 from datetime import timedelta
 from inspect import signature
 from typing import (
@@ -120,7 +119,6 @@ class GraphQLRouter(
         self,
         schema: BaseSchema,
         path: str = "",
-        graphiql: bool | None = None,
         graphql_ide: GraphQL_IDE | None = "graphiql",
         allow_queries_via_get: bool = True,
         keep_alive: bool = False,
@@ -187,16 +185,7 @@ class GraphQLRouter(
         self.protocols = subscription_protocols
         self.connection_init_wait_timeout = connection_init_wait_timeout
         self.multipart_uploads_enabled = multipart_uploads_enabled
-
-        if graphiql is not None:
-            warnings.warn(
-                "The `graphiql` argument is deprecated in favor of `graphql_ide`",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-            self.graphql_ide = "graphiql" if graphiql else None
-        else:
-            self.graphql_ide = graphql_ide
+        self.graphql_ide = graphql_ide
 
         @self.get(
             path,
@@ -210,7 +199,7 @@ class GraphQLRouter(
                     )
                 },
             },
-            include_in_schema=graphiql or allow_queries_via_get,
+            include_in_schema=graphql_ide is not None or allow_queries_via_get,
         )
         async def handle_http_get(  # pyright: ignore
             request: Request,
